@@ -7,8 +7,8 @@ glide <- function(formula,exposure_coeff=NULL,genotype_columns=NULL,data,
     thetime=Sys.time()
     thetime=as.character(structure(thetime,class=c('POSIXt','POSIXct')))
   }
-  if (class(formula)=="character") formula=as.formula(formula)
-  if (class(exposure_coeff)=="data.frame")
+  if (inherits(formula,"character")) formula=as.formula(formula)
+  if (inherits(exposure_coeff,"data.frame"))
   {
     tmp=exposure_coeff[,1]
     names(tmp)=rownames(exposure_coeff)
@@ -101,7 +101,7 @@ glide <- function(formula,exposure_coeff=NULL,genotype_columns=NULL,data,
                    yfit=as.double(yfit),
                    y=as.double(y),
                    xmat=as.double(xmat),
-                   data_genotype=as.double(data.matrix(data_genotype)),
+                   data_genotype=data.matrix(data_genotype),
                    cormat_col=as.double(cormat_col),
                    PACKAGE="GLIDE")
       result$cormat_col
@@ -127,7 +127,7 @@ glide <- function(formula,exposure_coeff=NULL,genotype_columns=NULL,data,
                  yfit=as.double(yfit),
                  y=as.double(y),
                  xmat=as.double(xmat),
-                 data_genotype=as.double(data.matrix(data_genotype)),
+                 data_genotype=data.matrix(data_genotype),
                  cormat=as.double(cormat),
                  PACKAGE="GLIDE"
     )
@@ -208,4 +208,4 @@ glide <- function(formula,exposure_coeff=NULL,genotype_columns=NULL,data,
   out=out[order(out$observed_pvalue),]
   class(out)=c(class(out),"glide","egger")
   return(out)
-}
\ No newline at end of file
+}
