@@ -10,7 +10,8 @@ double **double_vec_to_mat(double *Yvec, int nrow, int ncol, char opt);
 double *double_mat_to_vec(double **Ymat, int nrow, int ncol,char opt);
 int *int_vec(int n);
 void mydgemm (int M,int N,int K,double *A, double *B, double *C);
-void dgemm_(const char *transa, const char *transb, const int *m, const int *n, const int *k, const double *alpha, const double *a, const int *lda, const double *b, const int *ldb, const double *beta, double *c, const int *ldc);
+//void dgemm_(const char *transa, const char *transb, const int *m, const int *n, const int *k, const double *alpha, const double *a, const int *lda, const double *b, const int *ldb, const double *beta, double *c, const int *ldc);
+void dgemm_(const char *transa, const char *transb, const int *m, const int *n, const int *k, const double *alpha, const double *a, const int *lda, const double *b, const int *ldb, const double *beta, double *c, const int *ldc, size_t,  size_t);
 void dqrinv(double *xvec, int n, double tol, double *outvec);
 void dqrdc2_(double *, int *, int *, int *, double *, int *, double *, int *, double *);
 void dqrcf_(double *, int *, int *, double *, double *, int *, double *, int *);
